"""
All user-visible strings with gettext translation.
"""

# SnakeBite - Transcodes GStreamer-supported audio to MP3
# Copyright (C) 2008 Jason Gerard DeRose <jderose@jasonderose.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

from __future__ import absolute_import
from pyawesome.core import Core

_ = Core.gettext

markup_help = _("""
All audio files found in the <b>Source Folder</b> will be converted to MP3 (if they aren't arleady) and then saved in the <b>Destination Folder</b>.

After SnakeBite has finished, the <b>Destination Folder</b> will contain the same folders and files as the <b>Source Folder</b>, except all the files will have a <i>.mp3</i> extension.

Nothing in the <b>Source Folder</b> will be altered in any way.  Files that already exist in the <b>Destination Folder</b> will not be overwritten.
""")

strings = {
	# Window title
	'title_idle': _('SnakeBite MP3 Converter'),
	'description': _('Converts your audio files to MP3'),
	'title_active': _('Converting Audio Files...'),
	

	# Progress bars
	'progress_total': _('Processing file %(current)d of %(total)d'),
	'progress_file': _('Encoded %(time_completed)s of %(time_total)s'),
	
	# Buttons
	'button_transcode': _('Convert these Audio Files to MP3'),
	'button_abort': _('Abort Audio Conversion'),
	
	# Dialogs
	'dialog_src': _('Choose your Source Folder...'),
	'dialog_dst': _('Choose your Destination Folder...'),
	'dialog_close': _('Close SnakeBite?'),
	'dialog_summary': _('SnakeBite Complete'),
	
	# Longer messages, questions
	'message_close': _('Closing SnakeBite will abort the current\
 conversion. Close and abort?'),
 	'message_summary': _('Completed audio conversion in %(time_elapsed)s.'),
	
	'markup_help': markup_help,
	
	# Table row labels
	'label_src': _('Source Folder:'),
	'label_dst': _('Destination Folder:'),
	'label_total': _('Total Progress:'),
	'label_file': _('File Progress:'),
	'label_current_folder': _('Current Folder:'),
	'label_current_file': _('Current File:'),
	'label_mp3_bitrate': _('MP3 Bitrate:'),
	'label_settings': _('Settings:'),
	'label_progress': _('Progress:'),

	'label_help': _('Converting audio files to MP3 with SnakeBite'),
	
	# Misc
	'bitrate': _('%(kbps)d kbit/s'),
	
	
	# Used in filenames and/or directories
	'converted_audio': _('SnakeBite Converted MP3'),


	# Phrases used in the summary after conversion has finished:
	'summary_total': _('Of %(count)d files considered:'),
	
	'summary_success': _('%(count)d files were converted to MP3.'),
	'summary_mp3_hardlinked': _('%(count)d MP3 files were hard-linked.'),
	'summary_mp3_copied': _('%(count)d MP3 files were copied.'),

	'summary_preexisting': _('%(count)d preexisting files were ignored.'),
	'summary_non_audio': _('%(count)d non-audio files were ignored.'),

	'summary_transcode_error': _('%(count)d files had conversion errors.'),
	'summary_transcode_aborted': _('%(count)d file had its conversion aborted.'),
	
	'summary_remaining': _('%(count)d files were not yet processed.'),
}


